PolygonManager class

Constructors

PolygonManager()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmPoint(double x, double y, PolygonBean polygon) int?
Thi way make sure which point you click, return point index
isPointInsidePolygon(double x, double y, PolygonBean polygonBean) bool
Determine if the click is inside the polygon body
isRightPolygon(PolygonBean polygonBean) bool
This method can be used to determine whether the formed shape is a polygon or an irregular shape with intersecting line segments
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited