Polygon class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- Polygon
Constructors
-
Polygon({Key? key, required List<
Point> points, Color? edgeColor = Colors.red, double? edgeWidth = 2.0, Color? bodyColor = Colors.red, double? pointSize = 5, Color? pointColor = Colors.black, GestureDragUpdateCallback? onPanUpdate, GestureDragDownCallback? onPanDown, GestureDragEndCallback? onPanEnd, double? containerWidth, double? containerHeight, Widget? child}) -
const
Properties
- bodyColor → Color?
-
polygon color
final
- child → Widget?
-
final
- containerHeight → double?
-
final
- containerWidth → double?
-
final
- edgeColor → Color?
-
polygon's edge color
final
- edgeWidth → double?
-
polygon's edge width, default 2
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPanDown → GestureDragDownCallback?
-
final
- onPanEnd → GestureDragEndCallback?
-
final
- onPanUpdate → GestureDragUpdateCallback?
-
callback for GestureDetector Widget
final
- pointColor → Color?
-
polygon points' color
final
-
points
→ List<
Point> -
polygon's points,must be set
final
- pointSize → double?
-
polygon points Size, default 5
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Polygon> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited