PolygonBean class
Constructors
Properties
- bodyColor → Color?
-
final
- edgeColor → Color?
-
final
- edgeWidth → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointsColor → Color?
-
final
- pointsSize → double?
-
final
-
polygonPoint
→ List<
Point> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? edgeColor, Color? bodyColor, double? edgeWidth, required List< Point> polygonPoint, Color? pointsColor, double? pointsSize}) → PolygonBean -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited